==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Output/waveout/outputwaveoutfactory.h <==
/***************************************************************************
 *   Copyright (C) 2009-2014 by Ilya Kotov                                 *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef OUTPUTWAVEOUTFACTORY_H
#define OUTPUTWAVEOUTFACTORY_H

#include <QObject>
#include <QString>
#include <QIODevice>
#include <QWidget>
#include <qmmp/output.h>
#include <qmmp/outputfactory.h>


class OutputWaveOutFactory : public QObject, OutputFactory
{
Q_OBJECT
Q_INTERFACES(OutputFactory)

public:
    const OutputProperties properties() const;
    Output* create();
    Volume *createVolume();
    void showSettings(QWidget* parent);
    void showAbout(QWidget *parent);
    QTranslator *createTranslator(QObject *parent);
};

#endif

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Output/waveout/outputwaveoutfactory.h <==
/***************************************************************************
 *   Copyright (C) 2009-2019 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef OUTPUTWAVEOUTFACTORY_H
#define OUTPUTWAVEOUTFACTORY_H

#include <QObject>
#include <QString>
#include <QIODevice>
#include <QWidget>
#include <qmmp/output.h>
#include <qmmp/outputfactory.h>


class OutputWaveOutFactory : public QObject, OutputFactory
{
Q_OBJECT
Q_INTERFACES(OutputFactory)

public:
    OutputProperties properties() const;
    Output* create();
    Volume *createVolume();
    void showSettings(QWidget* parent);
    void showAbout(QWidget *parent);
    QString translation() const;
};

#endif
